@@ -104,6 +104,8 @@ SV* sqlite_db_rollback_hook( pTHX_ SV *dbh, SV *hook );
 SV* sqlite_db_update_hook( pTHX_ SV *dbh, SV *hook );
 int sqlite_db_set_authorizer( pTHX_ SV *dbh, SV *authorizer );
 AV* sqlite_compile_options();
+int sqlite_db_trace(pTHX_ SV *dbh, SV *func);
+int sqlite_db_profile(pTHX_ SV *dbh, SV *func);
 
 int sqlite_db_register_fts3_perl_tokenizer(pTHX_ SV *dbh);
 
@@ -140,4 +142,10 @@ newUTF8SVpvn(char *s, STRLEN len) {
 
 #endif /* #ifdef SvUTF8_on */
 
+#ifdef USE_64_BIT_INT
+#  ifdef _MSC_VER
+#    define atoll _atoi64
+#  endif
+#endif
+
 #endif /* #ifndef _DBDIMP_H */
